@@ -379,33 +379,41 @@ class KatRes:
 
 def auto_namespaced_kat_cls(res_name_or_kind: str) -> Optional[Type[KatRes]]:
   definition = api_defs_man.find_def(res_name_or_kind)
+
   if definition:
     class NsdKatShell(KatRes):
       @classproperty
       def kind(self) -> str:
-        return definition['kind']
+        return definition.get('kind')
 
       @classproperty
       def res_name_plural(self) -> str:
-        return definition['name']
+        return definition.get('name')
 
       @classmethod
       def is_namespaced(cls) -> bool:
-        return True
+        return definition.get('namespaced')
 
       @classmethod
       def k8s_verb_methods(cls) -> Dict[str, Callable]:
-        def _list(namespace, **kwargs):
+        def _list_namespaced(namespace, **kwargs):
           return rest_backend.list_namespaced_resources(
-            definition['name'],
-            definition['apigroup'],
+            cls.res_name_plural,
+            definition['versioned_apigroup'],
             namespace,
             **kwargs
           )
 
+        def _list_cluster_scoped(**kwargs):
+          return rest_backend.list_cluster_scoped_resources(
+            cls.res_name_plural,
+            definition['versioned_apigroup'],
+            **kwargs
+          )
+
         def _delete(name, namespace, **kwargs):
           return rest_backend.delete_namespaced_resource(
-            definition['name'],
+            cls.res_name_plural,
             definition['apigroup'],
             namespace,
             name,
@@ -413,7 +421,7 @@ def auto_namespaced_kat_cls(res_name_or_kind: str) -> Optional[Type[KatRes]]:
           )
 
         return dict(
-          list=_list,
+          list=_list_namespaced if cls.is_namespaced() else _list_cluster_scoped,
           delete=_delete
         )
     return NsdKatShell
